@@ -99,14 +99,11 @@ qtm(nc)
 
 ## ------------------------------------------------------------------------
 tmap_mode("view")
-# if (Sys.getenv("USER") != "CRAN")
-tm_shape(nc) + tm_fill("BIR74", palette = sf.colors(5))
+if (Sys.getenv("USER") != "CRAN")
+  tm_shape(nc) + tm_fill("BIR74", palette = sf.colors(5))
 
 ## ------------------------------------------------------------------------
 ttm()
-#if (Sys.getenv("USER") != "CRAN")
-last_map()
-
-## ------------------------------------------------------------------------
-st_sf(a = 1:2, geom = st_sfc(st_point(0:1), st_linestring(rbind(c(1,1), c(2,2)))))
+if (Sys.getenv("USER") != "CRAN")
+   last_map()
 
