@@ -12,7 +12,7 @@ test_that("we can subset sf objects", {
 
   a = c("x", "y")
   g = st_sfc(pt1, pt2)
-  expect_silent(xxx <- st_sf(a, g, g)) 
+  expect_silent(xxx <- st_sf(a, g, g))
   expect_silent(st_sf(a, geom1 = g, geom2 = g, sf_column_name = "geom2"))
   x = st_sf(a, geom1 = g, geom2 = g, sf_column_name = "geom2")
   expect_silent(st_geometry(x) <- "geom2")
@@ -68,10 +68,15 @@ test_that("st_as_sf bulk points work", {
   meuse_sf = st_as_sf(x, coords = c("x", "y"), crs = 28992)
   xyz_sf = st_as_sf(x, coords = c("y", "x", "dist"))
   xym_sf = st_as_sf(x, coords = c("y", "x", "dist"), dim = "XYM")
-  xyzm_sf = st_as_sf(x, coords = c("x", "y", "dist", "zinc"), dim = "XYM")
+  xyzm_sf = st_as_sf(x, coords = c("x", "y", "dist", "zinc"), dim = "XYZM")
   expect_identical(class(meuse_sf), c("sf", "data.frame"))
   expect_identical(class(xyz_sf), c("sf", "data.frame"))
   expect_identical(class(xym_sf), c("sf", "data.frame"))
   expect_identical(class(xyzm_sf), c("sf", "data.frame"))
-  
+  expect_that(length(unclass(st_geometry(meuse_sf)[[1]])), equals(2L))
+  expect_that(length(unclass(st_geometry(xyz_sf)[[1]])), equals(3L))
+  expect_that(length(unclass(st_geometry(xym_sf)[[1]])), equals(3L))
+  expect_that(length(unclass(st_geometry(xyzm_sf)[[1]])), equals(4L))
+
+
 })
